@@ -20,8 +20,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""lck.cache
-   ---------
+"""lck.math
+   --------
 
    Various math related utilities."""
 
